<?php
  $timelines = carbon_get_post_meta( get_the_ID(), 'timeline_items' );
?>

<div class="timeline-container timeline-theme-8 timeline-post-<?php echo esc_attr(get_the_ID()); ?>" id="horizontal-8">
	<section class="timeline">
		<ol>
			<?php
			foreach ( $timelines as $timeline ) { ?>
			<li>
				<div class="timeline-text">
					<h5 class="timeline-title"><?php echo esc_html($timeline['timeline_item_title']); ?></h5>
					<p class="timeline-text"><?php echo esc_html($timeline['timeline_item_content']); ?></p>
					<span class="timeline-info"><?php echo esc_html($timeline['timeline_date']); ?></span>
				</div>
			</li>
			<?php } ?>
		</ol>
	  
		<div class="arrows">
			<button class="arrow arrow__prev disabled" disabled>
				<i class="fa fa-arrow-left"></i>
			<button class="arrow arrow__next">
				<i class="fa fa-arrow-right"></i>
			</button>
		</div>
	</section>
</div>

<script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/hammer.js/2.0.8/hammer.min.js"></script>
<script type="text/javascript">
  (function () {
  // VARIABLES
  const timeline = document.querySelector(".timeline ol"),
  elH = document.querySelectorAll(".timeline li > div"),
  arrows = document.querySelectorAll(".timeline .arrows .arrow"),
  arrowPrev = document.querySelector(".timeline .arrows .arrow__prev"),
  arrowNext = document.querySelector(".timeline .arrows .arrow__next"),
  firstItem = document.querySelector(".timeline li:first-child"),
  lastItem = document.querySelector(".timeline li:last-child"),
  xScrolling = 280,
  disabledClass = "disabled";

  // START
  window.addEventListener("load", init);

  function init() {
	setEqualHeights(elH);
	animateTl(xScrolling, arrows, timeline);
	setSwipeFn(timeline, arrowPrev, arrowNext);
	setKeyboardFn(arrowPrev, arrowNext);
  }

  // SET EQUAL HEIGHTS
  function setEqualHeights(el) {
	let counter = 0;
	for (let i = 0; i < el.length; i++) {if (window.CP.shouldStopExecution(0)) break;
	  const singleHeight = el[i].offsetHeight;

	  if (counter < singleHeight) {
		counter = singleHeight;
	  }
	}window.CP.exitedLoop(0);

	for (let i = 0; i < el.length; i++) {if (window.CP.shouldStopExecution(1)) break;
	  el[i].style.height = `${counter}px`;
	}window.CP.exitedLoop(1);
  }

  // CHECK IF AN ELEMENT IS IN VIEWPORT
  // http://stackoverflow.com/questions/123999/how-to-tell-if-a-dom-element-is-visible-in-the-current-viewport
  function isElementInViewport(el) {
	const rect = el.getBoundingClientRect();
	return (
	  rect.top >= 0 &&
	  rect.left >= 0 &&
	  rect.bottom <= (
	  window.innerHeight || document.documentElement.clientHeight) &&
	  rect.right <= (window.innerWidth || document.documentElement.clientWidth));

  }

  // SET STATE OF PREV/NEXT ARROWS
  function setBtnState(el, flag = true) {
	if (flag) {
	  el.classList.add(disabledClass);
	} else {
	  if (el.classList.contains(disabledClass)) {
		el.classList.remove(disabledClass);
	  }
	  el.disabled = false;
	}
  }

  // ANIMATE TIMELINE
  function animateTl(scrolling, el, tl) {
	let counter = 0;
	for (let i = 0; i < el.length; i++) {if (window.CP.shouldStopExecution(2)) break;
	  el[i].addEventListener("click", function () {
		if (!arrowPrev.disabled) {
		  arrowPrev.disabled = true;
		}
		if (!arrowNext.disabled) {
		  arrowNext.disabled = true;
		}
		const sign = this.classList.contains("arrow__prev") ? "" : "-";
		if (counter === 0) {
		  tl.style.transform = `translateX(-${scrolling}px)`;
		} else {
		  const tlStyle = getComputedStyle(tl);
		  // add more browser prefixes if needed here
		  const tlTransform =
		  tlStyle.getPropertyValue("-webkit-transform") ||
		  tlStyle.getPropertyValue("transform");
		  const values =
		  parseInt(tlTransform.split(",")[4]) +
		  parseInt(`${sign}${scrolling}`);
		  tl.style.transform = `translateX(${values}px)`;
		}

		setTimeout(() => {
		  isElementInViewport(firstItem) ?
		  setBtnState(arrowPrev) :
		  setBtnState(arrowPrev, false);
		  isElementInViewport(lastItem) ?
		  setBtnState(arrowNext) :
		  setBtnState(arrowNext, false);
		}, 1500);

		counter++;
	  });
	}window.CP.exitedLoop(2);
  }

  // ADD SWIPE SUPPORT FOR TOUCH DEVICES
  function setSwipeFn(tl, prev, next) {
	const hammer = new Hammer(tl);
	hammer.on("swipeleft", () => next.click());
	hammer.on("swiperight", () => prev.click());
  }

  // ADD BASIC KEYBOARD FUNCTIONALITY
  function setKeyboardFn(prev, next) {
	document.addEventListener("keydown", e => {
	  if (e.which === 50 || e.which === 59) {
		const timelineOfTop = timeline.offsetTop;
		const y = window.pageYOffset;
		if (timelineOfTop !== y) {
		  window.scrollTo(0, timelineOfTop);
		}
		if (e.which === 50) {
		  prev.click();
		} else if (e.which === 59) {
		  next.click();
		}
	  }
	});
  }
})();
</script>