<?php
$timelines = carbon_get_post_meta(get_the_ID(), 'timeline_items');
?>

<style>
    #vertical-basic {
        position: relative;
    }
    #timeline-vertical-6 .timeline__nav {
        position: absolute;
    }
    #timeline-vertical-6 .timeline__nav.fixed {
        position: fixed;
    }
</style>
<div id="vertical-basic">
    <div class="timeline-6 timeline-post-<?php echo esc_attr(get_the_ID()); ?>" id="timeline-vertical-6">
        <nav class="timeline__nav">
            <ul>
                <?php foreach ($timelines as $timeline) { ?>
                <li><span><?php echo esc_html($timeline['timeline_date']); ?></span></li>
                <?php } ?>
            </ul>
        </nav>
        <div class="timeline__section">
            <div class="wrapper">
                <?php foreach ($timelines as $timeline) { ?>
                <div class="item-timeline">
                    <div class="timeline-img">
                        <?php echo wp_get_attachment_image(esc_html($timeline['timeline_item_img']), 'full', '', array( 'class' => 'timeline__img' )); ?>
                    </div>
                    <div class="content-text">
                        <span class="milestone timeline-info"><?php echo esc_html($timeline['timeline_date']); ?></span>
                        <h2 class="the-title timeline-title"><?php echo esc_html($timeline['timeline_item_title']); ?></h2>
                        <p class="timeline-text"><?php echo wp_specialchars_decode($timeline['timeline_item_content']); ?></p>
                    </div>
                </div>
                <?php } ?>
            </div>
        </div>
    </div>
</div>


<script type="text/javascript">
jQuery(document).ready(function($) {
    $(() => {
        let stickyTop = 0,
            scrollTarget = false;

        let timeline = $(".timeline__nav"),
            items = $("li", timeline),
            milestones = $(".timeline__section .item-timeline"),
            offsetTop = parseInt(timeline.css("top"));

        const TIMELINE_VALUES = {
            start: 0,
            step: 30
        };


        $(window).resize(function() {
            timeline.removeClass("fixed");

            stickyTop = timeline.offset().top - offsetTop;

            $(window).trigger("scroll");
        }).trigger("resize");

        $(window).scroll(function() {
            var stickyWrap = $("#vertical-basic").offset().top;
            timeline.removeClass("fixed");
            if ($(window).scrollTop() > stickyWrap) {
                timeline.addClass("fixed");
            } else {
                timeline.removeClass("fixed");
            }
        }).trigger("scroll");

        items.find("span").click(function() {
            let li = $(this).parent(),
                index = li.index(),
                milestone = milestones.eq(index);

            if (!li.hasClass("active") && milestone.length) {
                scrollTarget = index;

                let scrollTargetTop = milestone.offset().top - 80;

                $("html, body").animate({
                    scrollTop: scrollTargetTop
                }, {
                    duration: 400,
                    complete: function complete() {
                        scrollTarget = false;
                    }
                });


            }
        });

        $(window).scroll(function() {
            let viewLine = $(window).scrollTop() + $(window).height() / 3,
                active = -1;

            if (scrollTarget === false) {
                milestones.each(function() {
                    if ($(this).offset().top - viewLine > 0) {
                        return false;
                    }

                    active++;
                });
            } else {
                active = scrollTarget;
            }

            timeline.css(
                "top",
                -1 * active * TIMELINE_VALUES.step + TIMELINE_VALUES.start + "px");


            items.filter(".active").removeClass("active");

            items.eq(active != -1 ? active : 0).addClass("active");
        }).trigger("scroll");
    });
});
</script>